# load packages and data
library(modelsummary)
library(urca)

# add custom functions to extract estimates (tidy) and goodness-of-fit (glance) information
tidy.ur.df <- function(s, ...) {
  
  ret <- data.frame(
    term      = row.names(coef(s@testreg)),
    estimate  = coef(s@testreg)[, "t value"],
    p.value = coef(s@testreg)[, "Pr(>|t|)"])
  ret
}

glance.ur.df <- function(s, ...) {

  ret <- data.frame(
    CriticalValue = t(s@cval[1,]),
    NumberObs = length(s@y))
  ret
}

tidy.customhtest <- function(s, ...) {
  
  ret <- data.frame(
    `term`    = "Test Statistic",
    estimate  = s$statistic[[1]],
    p.value   = s$p.value)
  ret
}

glance.customhtest <- function(s, ...) {
  
  ret <- data.frame(
    DF = s$parameter[[1]]
  )
  ret
}


tidy.mts <- function(s, ...) {
  
  colnames(s$se.coef) <- colnames(s$coef)
  
  ret <- data.frame(
    
    term= rownames(s$coef),
    
    estimate= c(
                s$coef[,1],
                s$coef[,2]
                ),
    
    std.error= c(
                 s$se.coef[,1],
                 s$se.coef[,2]
                 ),
   
    p.value = c(
                2*pt(abs(s$coef[,1])/s$se.coef[,1],df = nrow(s$data),lower.tail = F),
                2*pt(abs(s$coef[,2])/s$se.coef[,2],df = nrow(s$data),lower.tail = F)
                ),

    group=c(
            rep(colnames(s$coef)[1],times = nrow(s$coef)),
            rep(colnames(s$coef)[2],times = nrow(s$coef))
            )
  ) 
  
  ret
}

glance.mts <- function(s, ...) {
  
  ret <- data.frame(
    nobs = nrow(s$data)
  )
  ret
}

tidy.customdf <- function(s, ...) {
  
  ret <- data.frame(
    
    term = s$term,
    
    estimate= s$estimate,
    
    std.error = s$std.error
    
    )
  
  ret
}

glance.customdf <- function(s, ...) {
  
  ret <- data.frame(
  )
  ret
}

hypothesis_test <- function(x){
  out <- ifelse(x@cval[grep("^tau", rownames(x@cval)), "5pct", drop = FALSE]>
                  coef(x@testreg)["z.lag.1","t value"], 
                "No", 
                "Yes")
  return(out)
}


