library(tidyverse)
library(magrittr)
library(readxl)
library(writexl)

source("us_data.R")

## The following countries are kept on the dataset but
##     have limited data (i.e. data starts after 1995-I):
##    Italy, Netherlands

##############################################
### Manufacturing Value Added Share on GDP ###
##############################################

countries <- c("Austria", "Belgium", "Switzerland", "Costa Rica", 
               "Czechia", "Germany", "Denmark", "Spain", "Finland", "France", 
               "United Kingdom", "Hungary", "Italy", "Japan", "Luxembourg", 
               "Latvia", "Netherlands", "Portugal", "Sweden", "United States")

data_manu_share_current <- read_xlsx("GDP_VA_Luiz.xlsx",
                                      sheet = "Manufacturing share, current",
                                      col_names = TRUE) 
data_manu_share_current %<>%
  pivot_longer(cols = names(data_manu_share_current)[which(names(data_manu_share_current) != "Paises")],
               names_to = "time") %>%
  rename(country = "Paises") %>%
  mutate(price = "current")%>%
  filter(country != "USA")

data_manu_share_volume <- read_xlsx("GDP_VA_Luiz.xlsx", 
                                      sheet = "Manufacturing share, volume",
                                      col_names = TRUE) 
data_manu_share_volume %<>%
  pivot_longer(cols = names(data_manu_share_volume)[which(names(data_manu_share_volume) != "Paises")],
               names_to = "time") %>%
  rename(country = "Paises") %>%
  mutate(price = "volume") %>%
  filter(country != "USA")

# Volume data is in 2012 US dollars
data_usa <- read_xlsx("usa_quarterly_data.xlsx",
                       col_names = TRUE) %>% 
  bind_rows(new_data) %>%
  select(time, country, volume, current) %>%
  pivot_longer(cols = c("volume", "current"),
               names_to = "price")

# 
data_manu_share <- data_manu_share_current %>%
  bind_rows(data_manu_share_volume) %>%
  mutate(country = case_when(country == "AUS" ~ "Australia",
                             country == "AUT" ~ "Austria",
                             country == "BEL" ~ "Belgium",
                             country == "CAN" ~ "Canada",
                             country == "CHE" ~ "Switzerland",
                             country == "CHL" ~ "Chile",
                             country == "COL" ~ "Colombia",
                             country == "CRI" ~ "Costa Rica",
                             country == "CZE" ~ "Czechia",
                             country == "DEU" ~ "Germany",
                             country == "DNK" ~ "Denmark",
                             country == "ESP" ~ "Spain",
                             country == "EST" ~ "Estonia",
                             country == "HUN" ~ "Hungary",
                             country == "IRL" ~ "Ireland",
                             country == "ISL" ~ "Iceland",
                             country == "FIN" ~ "Finland",
                             country == "FRA" ~ "France",
                             country == "GBR" ~ "United Kingdom",
                             country == "GRC" ~ "Greece",
                             country == "ISR" ~ "Israel",
                             country == "ITA" ~ "Italy",
                             country == "JPN" ~ "Japan",
                             country == "KOR" ~ "Korea",
                             country == "LTU" ~ "Lithuania",
                             country == "LUX" ~ "Luxembourg",
                             country == "LVA" ~ "Latvia",
                             country == "MEX" ~ "Mexico",
                             country == "NLD" ~ "Netherlands",
                             country == "NOR" ~ "Norway",
                             country == "NZL" ~ "New Zealand",
                             country == "POL" ~ "Poland",
                             country == "PRT" ~ "Portugal",
                             country == "SVK" ~ "Slovakia",
                             country == "SVN" ~ "Slovenia",
                             country == "SWE" ~ "Sweden",
                             country == "TUR" ~ "Turkey",
                             country == "USA" ~ "United States",
                             country == "EA20" ~ "Euro Area",
                             country == "EU27_2020" ~ "European Union",
                             T ~ country
  )) %>% 
  bind_rows(data_usa) %>%
  filter(country %in% countries) %>%
  drop_na(value) %>%
  mutate(id = paste0(country,time,price))

minus_time_usa <- data_manu_share$time[!(data_manu_share$time %in% data_usa$time)] %>% 
  unique()

################### GDP_USD_Luiz.csv
# Reference area: 
# Economic activity: Not applicable
# Price base: Current prices
# Adjustment: Calendar and seasonally adjusted
# Transaction: Gross domestic product
# Unit of measure: "US dollars, PPP converted"

data_gdp_complete <- read_csv("GDP_USD_Luiz.csv") %>%
  rename(country = "Reference area",
         price = "Price base",
         unit = "Unit of measure",
         time = "TIME_PERIOD",
         gdp = "OBS_VALUE") %>%
  select(country, time, price, gdp) %>%
  mutate(price = case_when(price == "Current prices" ~ "current",
                           price == "Chain linked volume (rebased)" ~ "volume")) %>%
  mutate(country = case_when(country == "Euro area (20 countries)" ~ "Euro Area",
                             country == "European Union (27 countries from 01/02/2020)" ~ "European Union",
                             T ~ country),
         id = paste0(country, time, price))%>%
  filter(country %in% countries,
         id %in% data_manu_share$id) %>%
  select(-id)

# Data Frame com PIB agregado de todos os países do grupo, por período
data_gdp_complete_group <- data_gdp_complete %>%
  group_by(time, price) %>% 
  summarise(total_gdp = sum(gdp))

data_gdp_complete %<>% left_join(data_gdp_complete_group, 
                                  by = c("time","price")) %>%
                        mutate(share_gdp = gdp/total_gdp)

##################
### Final Data ###
##################

final_data <- data_manu_share %>% 
  select(-id) %>% 
  full_join(data_gdp_complete, 
            by = c("time", "country", "price"))


final_data_current <- final_data %>%
  filter(price == "current") %>%
  mutate(contribution_manu = share_gdp*value) %>%
  group_by(time) %>%
  summarise(manu_share_current = 100*sum(contribution_manu),
            country = "Group")

final_data_volume <- final_data %>%
  filter(price == "volume") %>%
  mutate(contribution_manu = share_gdp*value) %>%
  group_by(time) %>%
  summarise(manu_share_volume = 100*sum(contribution_manu),
            country = "Group")

final_group_data <- final_data_current %>% full_join(final_data_volume, by = c("time", "country")) %>%
  relocate(time, country, everything())

    write_xlsx(final_group_data, path = "final_group_data.xlsx")

